@@ -139,7 +139,7 @@ class Smart(Generic[T]):
         if not callable(_callable):
             raise TypeError("Object is not callable.")
 
-        self._location: str = ''
+        self._trace: str = ''
 
         self._callable = _callable
         self._params: Dict[str, Any] = dict()
@@ -173,23 +173,21 @@ class Smart(Generic[T]):
             An class instance.
 
         """
-        callable_name = strutil.join_objects(self._location, typeutil.get_name(self._callable))
         params = self.dict
 
         if self.check_overrides:
             typeutil.check_overrides(
                 params=params,
                 kwargs=kwargs,
-                callable_name=callable_name,
+                trace=strutil.join_objects(self._trace, typeutil.get_name(self._callable)),
                 raise_error=self.strict,
             )
 
         params.update(kwargs)
 
         return self._init(
-            callable_name=callable_name,
             callable_=self._callable,
-            location=self._location,
+            trace=self._trace,
             args=args,
             kwargs=params,
         )
@@ -449,7 +447,7 @@ class Smart(Generic[T]):
         cls,
         source: Union['Smart', Mapping[str, Any], Sequence[str], str, Path],
         key: Optional[str] = None,
-    ) -> Any:
+    ) -> 'Smart':
         """Loads object from the given source.
 
         Args:
@@ -457,13 +455,13 @@ class Smart(Generic[T]):
             key: Key of source dictionary.
 
         Returns:
-            Instance of loaded source.
+            Smart object with loaded given source.
 
         Raises:
             TypeError if given source is not supported.
 
         """
-        return cls().update_from(source=source, source_key=key).init()
+        return cls().update_from(source=source, source_key=key)
 
     def init(
         self,
@@ -483,12 +481,12 @@ class Smart(Generic[T]):
         if key is None:
             obj = self._init_object(
                 obj=self._params,
-                location=self._location,
+                trace=self._trace,
             )
         else:
             obj = self._init_object(
                 obj=self.get(key),
-                location=strutil.join_keys(self._location, key),
+                trace=strutil.join_keys(self._trace, key),
             )
 
             if persist:
@@ -524,42 +522,11 @@ class Smart(Generic[T]):
             override=False,
         )
 
-        return typeutil.convert_to_primitive_types(
+        return typeutil.convert_to_primitives(
             obj=smart.dict,
-            missing_value=self.missing_value,
+            unknown_type=self.missing_value,
         )
 
-    def metadata(
-        self,
-        save_to: Optional[Path] = None,
-    ) -> Dict[str, Any]:
-        """Returns most important metadata of platform and project versions.
-
-        Args:
-            save_to: Path to save metadata.
-
-        Returns:
-            Dictionary with metadata.
-
-        """
-        metadata = dict(
-            **self.lab.metadata(),
-            params=typeutil.convert_to_primitive_types(
-                obj=self.dict,
-                missing_value=self.missing_value,
-            ),
-        )
-
-        if save_to:
-            metadata_history = load_data(save_to) if save_to.exists() else dict()
-            metadata_history[f'run{len(metadata_history) + 1:03d}'] = metadata
-            save_data(
-                data=metadata_history,
-                path=save_to,
-            )
-
-        return metadata
-
     def run(
         self,
         function: Optional[Callable[['Smart'], Any]] = None,
@@ -615,55 +582,57 @@ class Smart(Generic[T]):
                 path=args.path,
             )
         elif args.print:
-            if args.print == Print.PARAMS:
-                print_data(
-                    data=self.representation(
-                        skip_defaults=args.skip_defaults,
-                        merge_params=args.merge_params,
-                    ),
-                    fmt=args.format,
-                )
-            elif args.print == Print.DICT:
-                print_data(
-                    data=typeutil.convert_to_primitive_types(
-                        obj=self._params,
-                        missing_value=self.missing_value,
-                    ),
-                    fmt=args.format,
-                )
-            elif args.print == Print.KEYS:
-                print_data(
-                    data=tuple(self.keys(flatten=True)),
-                    fmt=args.format,
-                )
-            else:
-                raise NotImplementedError(f"Print '{args.print}' has not been implemented yet.")
+            print_data(
+                data=self._get_print_data(args),
+                fmt=args.format,
+            )
         elif function is None:
             self()
         else:
             function(self)
 
+    def _get_print_data(
+        self,
+        args: Arguments,
+    ) -> Any:
+        if args.print == Print.PARAMS:
+            return self.representation(
+                skip_defaults=args.skip_defaults,
+                merge_params=args.merge_params,
+            )
+
+        if args.print == Print.DICT:
+            return typeutil.convert_to_primitives(
+                obj=self._params,
+                unknown_type=self.missing_value,
+            )
+
+        if args.print == Print.KEYS:
+            return tuple(self.keys(flatten=True))
+
+        raise NotImplementedError(f"Print '{args.print}' has not been implemented yet.")
+
     def _init_object(
         self,
         obj: Any,
-        location: str,
+        trace: str,
     ) -> Any:
         if isinstance(obj, dict):
             if self.keyword in obj:
                 return self._init_from_dict(
                     dictionary=obj,
-                    location=location,
+                    trace=trace,
                 )
 
             return self._init_dict(
                 dictionary=obj,
-                location=location,
+                trace=trace,
             )
 
         if isinstance(obj, list):
             return self._init_list(
                 lst=obj,
-                location=location,
+                trace=trace,
             )
 
         return obj
@@ -671,12 +640,12 @@ class Smart(Generic[T]):
     def _init_dict(
         self,
         dictionary: Dict[str, Any],
-        location: str,
+        trace: str,
     ) -> Dict[str, Any]:
         return {
             key: self._init_object(
                 obj=value,
-                location=strutil.join_keys(location, key),
+                trace=strutil.join_keys(trace, key),
             )
             for key, value in dictionary.items()
         }
@@ -684,12 +653,12 @@ class Smart(Generic[T]):
     def _init_list(
         self,
         lst: List[Any],
-        location: str,
+        trace: str,
     ) -> List[Any]:
         return [
             self._init_object(
                 obj=element,
-                location=strutil.join_keys(location, str(index)),
+                trace=strutil.join_keys(trace, str(index)),
             )
             for index, element in enumerate(lst)
         ]
@@ -697,7 +666,7 @@ class Smart(Generic[T]):
     def _init_from_dict(
         self,
         dictionary: Dict[str, Any],
-        location: str,
+        trace: str,
     ) -> Any:
         kwargs, name, option = typeutil.parse_object(
             dictionary=dictionary,
@@ -706,50 +675,47 @@ class Smart(Generic[T]):
 
         if name == Smart.__name__:
             return self._init(
-                callable_name=strutil.join_objects(location, Smart.__name__),
                 callable_=Smart,
-                location=location,
+                trace=trace,
                 kwargs=kwargs,
             )
 
         if name in self.register.origins:
             name = self.register.origins[name]
         elif self.allow_only_registered_classes:
-            raise ObjectNotRegistered(name, location)
+            raise ObjectNotRegistered(name, trace)
 
-        callable_ = typeutil.import_callable(name, location=location)
-        callable_name = strutil.join_objects(location, typeutil.get_name(callable_))
+        callable_ = typeutil.import_callable(name, trace=trace)
 
         if option:
             if option == Option.SMART:
                 return self._init(
-                    callable_name=callable_name,
                     callable_=Smart,
-                    location=location,
+                    trace=trace,
                     args=(callable_,),
                     kwargs=kwargs,
                 )
 
             if option == Option.TYPE:
                 if kwargs:
-                    raise UnexpectedTypeOptionArguments(callable_name)
+                    raise UnexpectedTypeOptionArguments(
+                        trace=strutil.join_objects(trace, typeutil.get_name(callable_)),
+                    )
 
                 return callable_
 
-            raise ObjectInvalidOptionError(option, location)
+            raise ObjectInvalidOptionError(option, trace)
 
         return self._init(
-            callable_name=callable_name,
             callable_=callable_,
-            location=location,
+            trace=trace,
             kwargs=kwargs,
         )
 
     def _init(
         self,
-        callable_name: str,
         callable_: Callable,
-        location: str,
+        trace: str,
         args: Optional[Tuple[Any, ...]] = None,
         kwargs: Optional[Dict[str, Any]] = None,
     ) -> Any:
@@ -758,14 +724,16 @@ class Smart(Generic[T]):
 
         kwargs = self._init_dict(
             dictionary=kwargs,
-            location=location,
+            trace=trace,
         )
 
+        callable_trace = strutil.join_objects(trace, typeutil.get_name(callable_))
+
         if self.check_missings:
             typeutil.check_missings(
                 kwargs=kwargs,
                 missing_value=self.missing_value,
-                callable_name=callable_name,
+                trace=callable_trace,
                 raise_error=self.strict,
             )
 
@@ -774,18 +742,17 @@ class Smart(Generic[T]):
                 callable_=callable_,
                 args=args,
                 kwargs=kwargs,
-                callable_name=callable_name,
+                trace=callable_trace,
                 raise_error=self.strict,
             )
 
         try:
             obj = callable_(*args, **kwargs)
         except Exception as e:
-            raise RuntimeError(f"Error during instantiate '{callable_name}'; {e}") from e
+            raise RuntimeError(f"Error during instantiate '{callable_trace}'; {e}") from e
         else:
             if isinstance(obj, Smart):
-                obj._location = location
-
+                obj._trace = trace
             return obj
 
     def _object_representation(
