@@ -19,35 +19,35 @@ def flatten_keys(
 
 def find_nested(
     dictionary: Dict[str, Any],
-    name: str,
+    key: str,
     set_mode: bool = False,
     required: bool = False,
 ) -> Tuple[Dict[str, Any], str]:
-    *nested_keys, last_key = name.split(strutil.KEY_SEPARATOR)
+    *nested_keys, last_key = key.split(strutil.KEY_SEPARATOR)
 
     key_list = list()
-    for key in nested_keys:
-        key_list.append(key)
-        if key not in dictionary:
+    for k in nested_keys:
+        key_list.append(k)
+        if k not in dictionary:
             if set_mode:
-                dictionary[key] = dict()
+                dictionary[k] = dict()
             else:
-                location = strutil.KEY_SEPARATOR.join(key_list)
-                raise KeyError(f"Param '{location}' is not in dictionary.")
+                key_trace = strutil.KEY_SEPARATOR.join(key_list)
+                raise KeyError(f"Param '{key_trace}' is not in dictionary.")
 
-        if not isinstance(dictionary[key], dict):
+        if not isinstance(dictionary[k], dict):
             if set_mode:
-                dictionary[key] = dict()
+                dictionary[k] = dict()
             else:
-                location = strutil.KEY_SEPARATOR.join(key_list)
-                raise ValueError(f"Param '{location}' is not dictionary.")
+                key_trace = strutil.KEY_SEPARATOR.join(key_list)
+                raise ValueError(f"Param '{key_trace}' is not dictionary.")
 
-        dictionary = dictionary[key]
+        dictionary = dictionary[k]
 
     if required and last_key not in dictionary:
         key_list.append(last_key)
-        location = strutil.KEY_SEPARATOR.join(key_list)
-        raise KeyError(f"Param '{location}' is not in dictionary.")
+        key_trace = strutil.KEY_SEPARATOR.join(key_list)
+        raise KeyError(f"Param '{key_trace}' is not in dictionary.")
 
     return dictionary, last_key
 
