@@ -22,15 +22,11 @@ class ClassComposition:
         smart_cls: Smart[Class],
         smart: Smart,
         unknown: Any,
-        smart_cls_with_default: Smart[Class] = Smart(ClassChild, arg1="argument1"),
-        smart_cls_with_only_default_generic=Smart(),
     ) -> None:
         self.vanilla_cls = vanilla_cls
         self.smart_cls = smart_cls
         self.smart = smart
         self.unknown = unknown
-        self.smart_cls_with_default = smart_cls_with_default
-        self.smart_cls_with_only_default_generic = smart_cls_with_only_default_generic
 
 
 class ClassCompositionChild(ClassComposition):
@@ -42,8 +38,6 @@ class ClassCompositionChild(ClassComposition):
         unknown: Any,
         no_type,
         *args: Any,
-        smart_cls_with_default: Smart[Class] = Smart(ClassChild, arg1="argument1"),
-        smart_cls_with_only_default_generic=Smart(),
         with_only_default_primitive=11,
         **kwargs: Any,
     ) -> None:
@@ -52,8 +46,6 @@ class ClassCompositionChild(ClassComposition):
             smart_cls=smart_cls,
             smart=smart,
             unknown=unknown,
-            smart_cls_with_default=smart_cls_with_default,
-            smart_cls_with_only_default_generic=smart_cls_with_only_default_generic,
         )
         self.no_type = no_type
         self.args = args
