@@ -174,27 +174,6 @@ class TestSmartRepresentationCase(IntegrationCase):
 
         self.assertEqual(expected, actual)
 
-    def test_metadata(self) -> None:
-        self.smart.lab.metadata = Mock(return_value=dict(user='user'))  # type: ignore
-
-        actual = self.smart.metadata()
-
-        self.assertSetEqual({'user', 'params'}, set(actual))
-
-    def test_metadata__save(self) -> None:
-        self.smart.lab.metadata = Mock(return_value=dict(user='user'))  # type: ignore
-
-        with tempfile.TemporaryDirectory() as dirname:
-            filepath = Path(dirname, 'meta.yaml')
-            filepath.write_text('run001:\n  user: root\n  params: sth')
-
-            self.smart.metadata(save_to=filepath)
-
-            self.assertEqual(
-                'run001:\n  user: root\n  params: sth\nrun002:\n  user: user\n  params: {}\n',
-                filepath.read_text(),
-            )
-
 
 class TestCheckCase(IntegrationCase):
     def setUp(self) -> None:
@@ -271,14 +250,14 @@ class TestCheckCase(IntegrationCase):
         self.assertEqual('88', obj.arg2)
         warnings.warn.assert_called()
 
-    def test_init_class__location(self) -> None:
+    def test_init_class__trace(self) -> None:
         smart = Smart(Smart, nested=[{'class': 'Smart'}])
-        smart._location = 'location'
+        smart._trace = 'trace'
 
         obj = smart()
 
         self.assertIsInstance(obj, Smart)
-        self.assertEqual('location.nested.0', obj.get('nested')[0]._location)
+        self.assertEqual('trace.nested.0', obj.get('nested')[0]._trace)
 
     def test_init_class__raise(self) -> None:
         smart = Smart(RaiseClass)
